BufferedReader

Struct BufferedReader 

pub struct BufferedReader<'a, const N: usize> { /* private fields */ }
read a file a large buffer at a time and provide access to a slice in that buffer

Implementations

Source

impl<'a, const N: usize> BufferedReader<'a, N>

pub const fn new() -> Self

pub fn with_file(self, file: &'a File, read_limit: FileSize) -> Self

pub fn rebind<'b>(self) -> Result<BufferedReader<'b, N>>

Reset to idle state and re-type with a fresh lifetime 'b.