FileInfo

Struct FileInfo 

pub struct FileInfo {
    pub file: File,
    pub path: PathBuf,
    pub size: u64,
}
Open File coupled with its filesystem location and most useful information

The attached context for the File is kept minimal to make it easy to construct without unnecessary kernel queries, but allowing users to:

  • associate the file received in callbacks to the request (by its path)
  • get the file’s most useful metadata information

Fields

file: Filepath: PathBufsize: u64

Implementations

Source

impl FileInfo

pub fn new_from_path(path: impl Into<PathBuf>) -> Result<Self>

Create new instance by opening a file from a given path and reading its metadata

pub fn new_from_path_and_file( path: impl Into<PathBuf>, file: File, ) -> Result<Self>

Create new instance by using already open file and only reading its metadata