pub struct SequentialFileReader<'a> { /* private fields */ }Expand description
Reader for non-seekable files.
Implements read-ahead using io_uring.
Implementations
Sourceimpl<'a> SequentialFileReader<'a>
impl<'a> SequentialFileReader<'a>
Sourcepub fn set_path(&mut self, path: impl AsRef<Path>) -> Result<()>
pub fn set_path(&mut self, path: impl AsRef<Path>) -> Result<()>
Open file under path, check its metadata to determine read limit and add it to the reader.
See add_owned_file_to_prefetch for more details.
Sourcepub fn add_owned_file_to_prefetch(
&mut self,
file: File,
read_limit: FileSize,
) -> Result<()>
pub fn add_owned_file_to_prefetch( &mut self, file: File, read_limit: FileSize, ) -> Result<()>
Add file to read. Starts reading the file as soon as a buffer is available.
This function uses the direct io settings set in SequentialFileReaderBuilder.
A direct io mode reader is safe to use with non direct io files. However, passing direct io mode files to the reader in non direct io mode might result in an io error due to unaligned read.
It is up to the end user to ensure that they are passing files that conform to
the direct io settings of this SequentialFileReader.
The read finishes when EOF is reached or read_limit bytes are read.
The read_limit must be less than or equal to the file size when in direct io mode.
Multiple files can be added to the reader and they will be read-ahead in FIFO order.
Reader takes ownership of the file and will drop it after it’s done reading
and move_to_next_file is called.
Sourcepub fn rebind<'b>(self) -> Result<SequentialFileReader<'b>>
pub fn rebind<'b>(self) -> Result<SequentialFileReader<'b>>
Reset to idle state and re-type with a fresh lifetime 'b.
Drains the prefetch queue (cancels in-flight reads) before returning.