pub struct FileInfo {
pub file: File,
pub path: PathBuf,
pub size: u64,
}Expand description
Open File coupled with its filesystem location and most useful information
The attached context for the File is kept minimal to make it easy to construct
without unnecessary kernel queries, but allowing users to:
- associate the file received in callbacks to the request (by its path)
- get the file’s most useful metadata information
Fields
file: Filepath: PathBufsize: u64Implementations